@@ -15,7 +15,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '5.07';
+our $VERSION = '5.09';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -161,6 +161,21 @@ L<Minion::Command::minion::job>.
 
   $ ./myapp.pl minion job
 
+To manage background worker processes with systemd, you can use a unit
+configuration file like this.
+
+  [Unit]
+  Description=My Mojolicious application workers
+  After=postgresql.service
+
+  [Service]
+  Type=simple
+  ExecStart=/home/sri/myapp/myapp.pl minion worker -m production
+  KillMode=process
+
+  [Install]
+  WantedBy=multi-user.target
+
 Every job can fail or succeed, but not get lost, the system is eventually
 consistent and will preserve job results for as long as you like, depending on
 L</"remove_after">. While individual workers can fail in the middle of
@@ -275,8 +290,8 @@ C<1800> (30 minutes).
   $minion   = $minion->remove_after(86400);
 
 Amount of time in seconds after which jobs that have reached the state
-C<finished> will be removed automatically by L</"repair">, defaults to
-C<172800> (2 days).
+C<finished> and have no unresolved dependencies will be removed automatically by
+L</"repair">, defaults to C<172800> (2 days).
 
 =head2 tasks
 
@@ -441,6 +456,13 @@ Number of jobs in C<inactive> state that are scheduled to run at specific time
 in the future or have unresolved dependencies. Note that this field is
 EXPERIMENTAL and might change without warning!
 
+=item enqueued_jobs
+
+  enqueued_jobs => 100000
+
+Rough estimate of how many jobs have ever been enqueued. Note that this field is
+EXPERIMENTAL and might change without warning!
+
 =item failed_jobs
 
   failed_jobs => 100
