@@ -119,7 +119,7 @@ sub repair {
   my $fail = $db->query(
     "select id, retries from minion_jobs as j
      where state = 'active'
-       and not exists(select 1 from minion_workers where id = j.worker)"
+       and not exists (select 1 from minion_workers where id = j.worker)"
   )->hashes;
   $fail->each(sub { $self->fail_job(@$_{qw(id retries)}, 'Worker went away') });
 
@@ -128,32 +128,36 @@ sub repair {
     "update minion_jobs as j
      set finished = now(), result = to_json('Parent went away'::text),
        state = 'failed'
-     where parents != '{}' and cardinality(parents) != (
+     where parents <> '{}' and cardinality(parents) <> (
        select count(*) from minion_jobs where id = any(j.parents)
      ) and state = 'inactive'"
   );
 
-  # Old jobs
+  # Old jobs with no unresolved dependencies
   $db->query(
-    "delete from minion_jobs
-     where state = 'finished' and finished < now() - interval '1 second' * ?",
-    $minion->remove_after
+    "delete from minion_jobs as j
+     where finished <= now() - interval '1 second' * ? and not exists (
+       select 1 from minion_jobs
+       where j.id = any(parents) and state <> 'finished'
+     ) and state = 'finished'", $minion->remove_after
   );
 }
 
-sub reset { shift->pg->db->query('truncate minion_jobs, minion_workers') }
+sub reset {
+  shift->pg->db->query('truncate minion_jobs, minion_workers restart identity');
+}
 
 sub retry_job {
   my ($self, $id, $retries, $options) = (shift, shift, shift, shift || {});
 
   return !!$self->pg->db->query(
     "update minion_jobs
-     set priority = coalesce(?, priority), queue = coalesce(?, queue),
-       retried = now(), retries = retries + 1, state = 'inactive',
-       delayed = (now() + (interval '1 second' * ?))
+     set delayed = (now() + (interval '1 second' * ?)),
+       priority = coalesce(?, priority), queue = coalesce(?, queue),
+       retried = now(), retries = retries + 1, state = 'inactive'
      where id = ? and retries = ?
        and state in ('inactive', 'failed', 'finished')
-     returning 1", @$options{qw(priority queue)}, $options->{delay} // 0, $id,
+     returning 1", $options->{delay} // 0, @$options{qw(priority queue)}, $id,
     $retries
   )->rows;
 }
@@ -162,10 +166,13 @@ sub stats {
   my $self = shift;
 
   my $stats = $self->pg->db->query(
-    "select state::text || '_jobs', count(*) from minion_jobs group by state
+    "select 'enqueued_jobs', case when is_called then last_value else 0 end
+     from minion_jobs_id_seq
+     union all
+     select state::text || '_jobs', count(*) from minion_jobs group by state
      union all
      select 'delayed_jobs', count(*) from minion_jobs
-     where (delayed > now() or parents != '{}') and state = 'inactive'
+     where (delayed > now() or parents <> '{}') and state = 'inactive'
      union all
      select 'inactive_workers', count(*) from minion_workers
      union all
@@ -205,7 +212,7 @@ sub _try {
          select count(*) from minion_jobs
          where id = any(j.parents) and state = 'finished'
        )) and queue = any (?) and state = 'inactive' and task = any (?)
-       order by priority desc, created
+       order by priority desc, id
        limit 1
        for update skip locked
      )
@@ -629,6 +636,13 @@ Number of jobs in C<inactive> state that are scheduled to run at specific time
 in the future or have unresolved dependencies. Note that this field is
 EXPERIMENTAL and might change without warning!
 
+=item enqueued_jobs
+
+  enqueued_jobs => 100000
+
+Rough estimate of how many jobs have ever been enqueued. Note that this field is
+EXPERIMENTAL and might change without warning!
+
 =item failed_jobs
 
   failed_jobs => 100
@@ -771,7 +785,6 @@ drop type if exists minion_state;
 
 -- 8 up
 alter table minion_jobs add constraint args check(jsonb_typeof(args) = 'array');
-create index on minion_jobs (state, priority desc, created);
 
 -- 9 up
 create or replace function minion_jobs_notify_workers() returns trigger as $$
@@ -796,3 +809,6 @@ drop function if exists minion_jobs_notify_workers();
 
 -- 10 up
 alter table minion_jobs add column parents bigint[] default '{}'::bigint[];
+
+-- 11 up
+create index on minion_jobs (state, priority desc, id);
